from distutils.core import setup
setup(
  name = 'drps',         # How you named your package folder (MyLib)
  packages = ['drps'],   # Chose the same as "name"
  version = '1.2',      # Start with a small number and increase it with every change you make
  license='MIT',        # Chose a license from here: https://help.github.com/articles/licensing-a-repository
  description = "A module that aim to make it faster to start your fullstack project with few inputs in short time.Also all neccessary modules are supplied within starting the project.",   # Give a short description about your library
  author = 'Ghazi',                   # Type in your name
  author_email = 'ghazi-z3balawi@putlook.com',      # Type in your E-Mail
  url = 'https://github.com/ghazigamer/',   # Provide either the link to your github or to your website
  download_url = 'https://github.com/ghazigamer/Django-React-Project-Setup/archive/refs/tags/v_01.zip',    # I explain this later on
  keywords = ['Project', 'Setup', 'For',"Django","And","React"],   # Keywords that define your package best
  install_requires=[            # I get to this in a second
          'django',
      ],
  classifiers=[
    'Development Status :: 5 - Production/Stable',      # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
    'Intended Audience :: Developers',      # Define that your audience are developers
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',   # Again, pick a license
    'Programming Language :: Python :: 3.9',
  ],
)


import os

def start_project():
    path: str = input("Please Enter the path of your project : ")
    is_path = os.path.exists(path)
    while is_path == False:
        path: str = input("Invalid Path. Please Enter the path of your project : ")
        is_path = os.path.exists(path)
    project_name = input("What the name of the project : ")
    django_project_app = input(
        "Please Enter the name of your Django project, and Django app name (separated by comma): "
    )
    django_project_name = django_project_app.split(",")[0]
    django_app_name = django_project_app.split(",")[1]

    react_project_app_name = input(
        "Please Enter the name of frontend side project and React app name (separated by comma) : "
    )
    react_project_name = react_project_app_name.split(",")[0]
    react_app_name = react_project_app_name.split(",")[1]

    venv_name = input("Please Enter the name of your virtual environment : ")
    python_command = f"cd {path} &&  mkdir {project_name} && cd {path}\\{project_name} && django-admin startproject {django_project_name} && cd {path}\\{project_name}\\{django_project_name} && python -m venv {venv_name} && django-admin startapp {django_app_name} &&  {venv_name}\\Scripts\\activate && python -m pip install django && python -m pip install djangorestframework && python -m pip install django-cors-headers && python -m pip install django-extensions"
    js_command = f"cd {path}\\{project_name} && mkdir {react_project_name} && cd {path}\\{project_name}\\{react_project_name} && npx create-react-app {react_app_name} && npm install axios && npm install react-router-dom"
    os.system(python_command)
    os.system(js_command)
    print("Project Created Successfully")


